Learn R Programming

fivethirtyeight (version 0.6.0)

fivethirtyeight: fivethirtyeight: Data and Code Behind the Stories and Interactives at 'FiveThirtyEight'

Description

An R package that provides access to the code and data sets published by FiveThirtyEight https://github.com/fivethirtyeight/data. Note that while we received guidance from editors at 538, this package is not officially published by 538. Contribute to this package at https://github.com/rudeboybert/fivethirtyeight.

Arguments

Examples

Run this code
# NOT RUN {
# Example usage:
library(fivethirtyeight)
# }
# NOT RUN {
head(bechdel)
# }
# NOT RUN {
# All information about any data set can be found in the help file:
# }
# NOT RUN {
?bechdel
# }
# NOT RUN {
# To view a list of all data sets:
# }
# NOT RUN {
data(package = "fivethirtyeight")
# }
# NOT RUN {
# To view a detailed list of all data sets:
# }
# NOT RUN {
vignette("fivethirtyeight", package = "fivethirtyeight")
# }
# NOT RUN {
# Some data sets include vignettes with an example analysis 
# (these are in the fivethirtyeightdata package):
# }
# NOT RUN {
vignette("bechdel", package = "fivethirtyeightdata")
# }
# NOT RUN {
# To browse all vignettes (these are in the fivethirtyeightdata package):
# }
# NOT RUN {
browseVignettes(package = "fivethirtyeightdata")
# }

Run the code above in your browser using DataLab